:icon: material/panorama-variant-outline

Panorama
========

For documentation purposes it might be useful to have an image of the measured
area with the measured points annotated. Total stations with integrated cameras
usually have a panorama capture on-board program, but it provides to way to
annotate the recorded points.

The panorama commands provide a way to capture frames of a panorama, and
merge them together with optional point annotations.

.. toctree::
    :maxdepth: 1

    measure
    process
